
.. |logical| replace:: `logical`_
.. _`logical`: `Logical Operations`_

.. |Logical Operations| replace:: `Logical Operations`_
.. |logical operations| replace:: `logical operations`_


.. copyright:: Copyright ©  2001-2009 Aleksey Gurtovoy and David Abrahams
   Distributed under the Boost Software License, Version 1.0. (See accompanying
   file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
